@@ -24,6 +24,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "meta.h"
 #include "scriptingutils.h"
 #include "workspace_wrapper.h"
+#include "scripting_model.h"
 #include "../client.h"
 #include "../thumbnailitem.h"
 #include "../options.h"
@@ -32,6 +33,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kstandarddirs.h>
 #include <KDE/KConfigGroup>
 #include <KDE/KDebug>
+#include <KDE/KGlobal>
 #include <KDE/KPluginInfo>
 #include <KDE/KServiceTypeTrader>
 #include <kdeclarative.h>
@@ -39,14 +41,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusPendingCallWatcher>
-#include <QtCore/QFutureWatcher>
-#include <QtCore/QSettings>
-#include <QtCore/QtConcurrentRun>
+#include <QFutureWatcher>
+#include <QSettings>
+#include <QtConcurrentRun>
 #include <QtDeclarative/QDeclarativeContext>
 #include <QtDeclarative/QDeclarativeEngine>
 #include <QtDeclarative/QDeclarativeView>
 #include <QtDeclarative/qdeclarative.h>
-#include <QtGui/QMenu>
+#include <QMenu>
 #include <QtScript/QScriptEngine>
 #include <QtScript/QScriptValue>
 
@@ -57,11 +59,17 @@ QScriptValue kwinScriptPrint(QScriptContext *context, QScriptEngine *engine)
         return engine->undefinedValue();
     }
     QString result;
+    QTextStream stream(&result);
     for (int i = 0; i < context->argumentCount(); ++i) {
         if (i > 0) {
-            result.append(" ");
+            stream << " ";
+        }
+        QScriptValue argument = context->argument(i);
+        if (KWin::Client *client = qscriptvalue_cast<KWin::Client*>(argument)) {
+            client->print<QTextStream>(stream);
+        } else {
+            stream << argument.toString();
         }
-        result.append(context->argument(i).toString());
     }
     script->printMessage(result);
 
@@ -215,20 +223,10 @@ KWin::AbstractScript::AbstractScript(int id, QString scriptName, QString pluginN
     if (m_pluginName.isNull()) {
         m_pluginName = scriptName;
     }
-#ifdef KWIN_BUILD_SCREENEDGES
-    connect(KWin::Workspace::self()->screenEdge(), SIGNAL(activated(ElectricBorder)), SLOT(borderActivated(ElectricBorder)));
-#endif
 }
 
 KWin::AbstractScript::~AbstractScript()
 {
-#ifdef KWIN_BUILD_SCREENEDGES
-    for (QHash<int, QList<QScriptValue> >::const_iterator it = m_screenEdgeCallbacks.constBegin();
-            it != m_screenEdgeCallbacks.constEnd();
-            ++it) {
-        KWin::Workspace::self()->screenEdge()->unreserve(static_cast<KWin::ElectricBorder>(it.key()));
-    }
-#endif
 }
 
 KConfigGroup KWin::AbstractScript::config() const
@@ -258,9 +256,10 @@ void KWin::AbstractScript::globalShortcutTriggered()
     callGlobalShortcutCallback<KWin::AbstractScript*>(this, sender());
 }
 
-void KWin::AbstractScript::borderActivated(KWin::ElectricBorder edge)
+bool KWin::AbstractScript::borderActivated(KWin::ElectricBorder edge)
 {
     screenEdgeActivated(this, edge);
+    return true;
 }
 
 void KWin::AbstractScript::installScriptFunctions(QScriptEngine* engine)
@@ -530,7 +529,9 @@ void KWin::ScriptUnloaderAgent::scriptUnload(qint64 id)
 
 KWin::DeclarativeScript::DeclarativeScript(int id, QString scriptName, QString pluginName, QObject* parent)
     : AbstractScript(id, scriptName, pluginName, parent)
-    , m_view(new QDeclarativeView())
+    , m_engine(new QDeclarativeEngine(this))
+    , m_component(new QDeclarativeComponent(m_engine, this))
+    , m_scene(new QGraphicsScene(this))
 {
 }
 
@@ -543,28 +544,50 @@ void KWin::DeclarativeScript::run()
     if (running()) {
         return;
     }
-    m_view->setAttribute(Qt::WA_TranslucentBackground);
-    m_view->setWindowFlags(Qt::X11BypassWindowManagerHint);
-    m_view->setResizeMode(QDeclarativeView::SizeViewToRootObject);
-    QPalette pal = m_view->palette();
-    pal.setColor(m_view->backgroundRole(), Qt::transparent);
-    m_view->setPalette(pal);
-
     // add read config
     KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(m_view->engine());
+    kdeclarative.setDeclarativeEngine(m_engine);
     kdeclarative.initialize();
     kdeclarative.setupBindings();
     installScriptFunctions(kdeclarative.scriptEngine());
-    qmlRegisterType<ThumbnailItem>("org.kde.kwin", 0, 1, "ThumbnailItem");
+    qmlRegisterType<DesktopThumbnailItem>("org.kde.kwin", 0, 1, "DesktopThumbnailItem");
+    qmlRegisterType<WindowThumbnailItem>("org.kde.kwin", 0, 1, "ThumbnailItem");
+    qmlRegisterType<KWin::ScriptingClientModel::ClientModel>();
+    qmlRegisterType<KWin::ScriptingClientModel::SimpleClientModel>("org.kde.kwin", 0, 1, "ClientModel");
+    qmlRegisterType<KWin::ScriptingClientModel::ClientModelByScreen>("org.kde.kwin", 0, 1, "ClientModelByScreen");
+    qmlRegisterType<KWin::ScriptingClientModel::ClientModelByScreenAndDesktop>("org.kde.kwin", 0, 1, "ClientModelByScreenAndDesktop");
+    qmlRegisterType<KWin::ScriptingClientModel::ClientFilterModel>("org.kde.kwin", 0, 1, "ClientFilterModel");
     qmlRegisterType<KWin::Client>();
 
-    m_view->rootContext()->setContextProperty("options", options);
+    m_engine->rootContext()->setContextProperty("options", options);
 
-    m_view->setSource(QUrl::fromLocalFile(scriptFile().fileName()));
+    m_component->loadUrl(QUrl::fromLocalFile(scriptFile().fileName()));
+    if (m_component->isLoading()) {
+        connect(m_component, SIGNAL(statusChanged(QDeclarativeComponent::Status)), SLOT(createComponent()));
+    } else {
+        createComponent();
+    }
+}
+
+void KWin::DeclarativeScript::createComponent()
+{
+    if (m_component->isError()) {
+        kDebug(1212) << "Component failed to load: " << m_component->errors();
+    } else {
+        m_scene->addItem(qobject_cast<QDeclarativeItem*>(m_component->create()));
+    }
     setRunning(true);
 }
 
+KWin::Scripting *KWin::Scripting::s_self = NULL;
+
+KWin::Scripting *KWin::Scripting::create(QObject *parent)
+{
+    Q_ASSERT(!s_self);
+    s_self = new Scripting(parent);
+    return s_self;
+}
+
 KWin::Scripting::Scripting(QObject *parent)
     : QObject(parent)
     , m_scriptsLock(new QMutex(QMutex::Recursive))
@@ -732,6 +755,7 @@ KWin::Scripting::~Scripting()
 {
     QDBusConnection::sessionBus().unregisterObject("/Scripting");
     QDBusConnection::sessionBus().unregisterService("org.kde.kwin.Scripting");
+    s_self = NULL;
 }
 
 QList< QAction * > KWin::Scripting::actionsForUserActionMenu(KWin::Client *c, QMenu *parent)
